***************
Craft providers
***************

Description
-----------
This project aims to provide Python interfaces for instantiating and executing
builds for a variety of target environments.

Initial providers include:
- LXD containers
- Multipass VMs

Host support is targeted for:
- Linux
- Mac OS X
- Windows

License
-------
Free software: GNU Lesser General Public License v3

Documentation
--------------
https://canonical-craft-providers.readthedocs-hosted.com/en/latest/

Contributing
------------
See the HACKING.rst document for details on how to contribute.
